@@ -6,7 +6,7 @@ require_once dirname(__FILE__) . '/Secret.php';
  * The Auth:: class provides a common abstracted interface into the
  * various backends for the Horde authentication system.
  *
- * $Horde: horde/lib/Auth.php,v 1.22.2.10 2003/01/03 12:48:39 jan Exp $
+ * $Horde: horde/lib/Auth.php,v 1.22.2.11 2003/02/18 00:33:00 jan Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -14,15 +14,18 @@ require_once dirname(__FILE__) . '/Secret.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.22.2.10 $
+ * @version $Revision: 1.22.2.11 $
  * @since   Horde 1.3
  * @package horde.auth
  */
 class Auth {
 
-    /** An array of capabilities, so that the driver can report which
-        operations it supports and which it doesn't.
-        @var array $capabilities */
+    /**
+     * An array of capabilities, so that the driver can report which
+     * operations it supports and which it doesn't.
+     *
+     * @var array $capabilities
+     */
     var $capabilities = array('add'         => false,
                               'update'      => false,
                               'remove'      => false,
@@ -30,6 +33,14 @@ class Auth {
                               'transparent' => false,
                               'loginscreen' => false);
 
+    /**
+     * Authentication error message.
+     *
+     * @var string $authError
+     */
+    var $authError = '';
+
+
     /**
      * Attempts to return a concrete Auth instance based on $driver.
      *
@@ -325,5 +336,29 @@ class Auth {
         return !empty($this->capabilities[$capability]);
     }
 
+    /**
+     * Sets the error message for an invalid authentication.
+     *
+     * @access private
+     *
+     * @param string $error  The error message/reason for invalid
+     *                       authentication.
+     */
+    function _setAuthError($error)
+    {
+        $this->authError = $error;
+    }
+
+    /**
+     * Gets the last error message for an invalid authentication.
+     *
+     * @access public
+     *
+     * @return string  The error message/reason for invalid authentication.
+     */
+    function getAuthError()
+    {
+        return $this->authError;
+    }
+
 }
-?>
