@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Auth/sql.php,v 1.21.2.6 2003/01/03 12:48:23 jan Exp $
+ * $Horde: horde/lib/Auth/sql.php,v 1.21.2.7 2003/02/18 00:33:02 jan Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -19,7 +19,9 @@
  *      'username'      The username with which to connect to the database.
  *      'password'      The password associated with 'username'.
  *      'database'      The name of the database.
- *      'table'         The name of the auth table in 'database'.
+ *
+ * Optional values:
+ *      'table'         The name of the auth table in 'database'. Defaults to 'horde_users'.
  *
  * Required by some database implementations:
  *      'options'       Additional options to pass to the database.
@@ -35,7 +37,7 @@
  *  );
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.21.2.6 $
+ * @version $Revision: 1.21.2.7 $
  * @since   Horde 1.3
  * @package horde.auth
  */
@@ -53,22 +55,21 @@ class Auth_sql extends Auth {
 
     /**
      * Hash containing connection parameters.
-     * @var array $params
+     * @var array $_params
      */
-    var $params = array();
+    var $_params = array();
 
     /**
      * Handle for the current database connection.
-     * @var object DB $db
+     * @var object DB $_db
      */
-    var $db;
+    var $_db;
 
     /**
      * Boolean indicating whether or not we're connected to the SQL server.
      * @var boolean $connected
      */
-    var $connected = false;
-
+    var $_connected = false;
 
     /**
      * Constructs a new SQL authentication object.
@@ -77,7 +78,7 @@ class Auth_sql extends Auth {
      */
     function Auth_sql($params = array())
     {
-        $this->params = $params;
+        $this->_params = $params;
     }
 
 
@@ -88,40 +89,40 @@ class Auth_sql extends Auth {
      */
     function _connect()
     {
-        if (!$this->connected) {
-            if (!is_array($this->params)) {
+        if (!$this->_connected) {
+            if (!is_array($this->_params)) {
                 Horde::fatal(new PEAR_Error(_("No configuration information specified for SQL authentication.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['phptype'])) {
+            if (!isset($this->_params['phptype'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'phptype' not specified in authentication configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['hostspec'])) {
+            if (!isset($this->_params['hostspec'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'hostspec' not specified in authentication configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['username'])) {
+            if (!isset($this->_params['username'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'username' not specified in authentication configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['password'])) {
+            if (!isset($this->_params['password'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'password' not specified in authentication configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['database'])) {
+            if (!isset($this->_params['database'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'database' not specified in authentication configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['table'])) {
-                Horde::fatal(new PEAR_Error(_("Required 'table' not specified in authentication configuration.")), __FILE__, __LINE__);
+            if (!isset($this->_params['table'])) {
+                $this->_params['table'] = 'horde_users';
             }
 
             /* Connect to the SQL server using the supplied parameters. */
             include_once 'DB.php';
-            $this->db = &DB::connect($this->params, true);
-            if (DB::isError($this->db)) {
+            $this->_db = &DB::connect($this->_params, true);
+            if (DB::isError($this->_db)) {
                 Horde::fatal(new PEAR_Error(_("Unable to connect to SQL server.")), __FILE__, __LINE__);
             }
 
             /* Enable the "portability" option. */
-            $this->db->setOption('optimize', 'portability');
+            $this->_db->setOption('optimize', 'portability');
 
-            $this->connected = true;
+            $this->_connected = true;
         }
 
         return true;
@@ -134,9 +135,9 @@ class Auth_sql extends Auth {
      */
     function _disconnect()
     {
-        if ($this->connected) {
-            $this->connected = false;
-            return $this->db->disconnect();
+        if ($this->_connected) {
+            $this->_connected = false;
+            return $this->_db->disconnect();
         }
 
         return true;
@@ -160,12 +161,12 @@ class Auth_sql extends Auth {
         $this->_connect();
 
         /* Build the SQL query. */
-        $query = 'SELECT user_uid FROM ' . $this->params['table'];
-        $query .= ' WHERE user_uid = ' . $this->db->quote($userID);
-        $query .= ' AND user_pass = ' . $this->db->quote(md5($credentials['password']));
+        $query = 'SELECT user_uid FROM ' . $this->_params['table'];
+        $query .= ' WHERE user_uid = ' . $this->_db->quote($userID);
+        $query .= ' AND user_pass = ' . $this->_db->quote(md5($credentials['password']));
 
         /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
 
         if (!DB::isError($result)) {
             $row = $result->fetchRow(DB_GETMODE_ASSOC);
@@ -196,11 +197,11 @@ class Auth_sql extends Auth {
         $this->_connect();
 
         /* Build the SQL query. */
-        $query = 'INSERT INTO ' . $this->params['table'] . ' (user_uid, user_pass) ';
-        $query .= 'VALUES (' . $this->db->quote($userID) . ', ' . $this->db->quote(md5($credentials['password'])) . ')';
+        $query = 'INSERT INTO ' . $this->_params['table'] . ' (user_uid, user_pass) ';
+        $query .= 'VALUES (' . $this->_db->quote($userID) . ', ' . $this->_db->quote(md5($credentials['password'])) . ')';
 
         /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
 
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
@@ -224,11 +225,11 @@ class Auth_sql extends Auth {
         $this->_connect();
 
         /* Build the SQL query. */
-        $query = 'UPDATE ' . $this->params['table'] . ' SET user_uid = ' . $this->db->quote($newID) . ', user_pass = ' . $this->db->quote(md5($credentials['password']));
-        $query .= 'WHERE user_uid = ' . $this->db->quote($oldID);
+        $query = 'UPDATE ' . $this->_params['table'] . ' SET user_uid = ' . $this->_db->quote($newID) . ', user_pass = ' . $this->_db->quote(md5($credentials['password']));
+        $query .= 'WHERE user_uid = ' . $this->_db->quote($oldID);
 
         /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
 
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
@@ -249,11 +250,11 @@ class Auth_sql extends Auth {
         $this->_connect();
 
         /* Build the SQL query. */
-        $query = 'DELETE FROM ' . $this->params['table'];
-        $query .= ' WHERE user_uid = ' . $this->db->quote($userID);
+        $query = 'DELETE FROM ' . $this->_params['table'];
+        $query .= ' WHERE user_uid = ' . $this->_db->quote($userID);
 
         /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
 
         if ($result !== DB_OK) {
             return (new PEAR_Error(_("Database query failed.")));
@@ -273,10 +274,10 @@ class Auth_sql extends Auth {
         $this->_connect();
 
         /* Build the SQL query. */
-        $query = 'SELECT user_uid from ' . $this->params['table'];
+        $query = 'SELECT user_uid from ' . $this->_params['table'];
 
         /* Execute the query. */
-        $result = $this->db->getAll($query, null, DB_FETCHMODE_ORDERED);
+        $result = $this->_db->getAll($query, null, DB_FETCHMODE_ORDERED);
 
         /* Loop through and build return value. */
         $users = array();
