@@ -1,8 +1,10 @@
 <?php
-/**
- * $Horde: horde/lib/Category.php,v 1.8.2.6 2002/04/05 01:24:19 jon Exp $
- * Copyright 1999-2002 Stephane Huther <shuther@bigfoot.com>
- * Copyright 2001-2002 Chuck Hagenbuch <chuck@horde.org>
+/*
+ * $Horde: horde/lib/Category.php,v 1.8.2.15 2003/04/28 19:59:07 jan Exp $
+ *
+ * Copyright 1999-2003 Stephane Huther <shuther@bigfoot.com>
+ * Copyright 2001-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
@@ -54,35 +56,31 @@ define('CATEGORY_SERIALIZE_FORMAT', SERIALIZEUNIT_BASIC);
  * everywhere. Every category must have a different name (for a same
  * groupid). A category may have different parent categories.
  *
- * @todo it migth be very interesting to transform the code, and using
- * XML/DOM instead, we could imagine it as a new driver, since we
- * would require a PHP extension for that. Another approach is to use
- * something similar to JTree (form Java)/and a node notion
- *
- * @note: -1 is used as the root, but it is a STRING, it is important
+ * @note -1 is used as the root, but it is a STRING, it is important
  * because database methods in PHP work only with strings, so we avoid
  * confusion.
  *
  * @author  Stephane Huther <shuther@bigfoot.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.8.2.6 $
+ * @version $Revision: 1.8.2.15 $
  * @since   Horde 2.1
  * @package horde.category
  */
 class Category {
 
     /**
-     * Array of all categories: indexed by name = parent
-     * right now, the format is array(name => array(parents)), but it could change
-     * to an XML/DOM organization
+     * Array of all categories: indexed by name = parent right now,
+     * the format is array(name => array(parents)), but it could
+     * change to an XML/DOM organization.
+     * @var array $categories
      */
-    var $categories = array();
+    var $_categories = array();
 
     /**
      * Hash containing connection parameters.
-     * @var array $params
+     * @var array $_params
      */
-    var $params = array();
+    var $_params = array();
 
     /**
      * Constructor
@@ -94,16 +92,19 @@ class Category {
      */
     function Category($params)
     {
-        $this->params = $params;
+        $this->_params = $params;
     }
 
     /**
-     * Attempts to return a concrete Category instance based on $driver.
+     * Attempts to return a concrete Category instance based on
+     * $driver.
      *
-     * @param string $driver The type of concrete Category subclass to return.
+     * @param mixed $driver  The type of concrete Category subclass to return.
      *                       This is based on the storage driver ($driver). The
-     *                       code is dynamically included.
-     * @param array  $params A hash containing any additional
+     *                       code is dynamically included. If $driver is an array,
+     *                       then we will look in $driver[0]/lib/Category/ for
+     *                       the subclass implementation named $driver[1].php.
+     * @param array $params  A hash containing any additional
      *                       configuration or connection parameters a subclass
      *                       might need.
      *                       here, we need 'groupid' = a string that defines
@@ -119,12 +120,19 @@ class Category {
         if (empty($driver) || (strcmp($driver, 'none') == 0)) {
             return new Category($params);
         }
-        include_once dirname(__FILE__) . '/Category/' . $driver . '.php';
+
+        if (!empty($app)) {
+            include_once $GLOBALS['registry']->getParam('fileroot', $app) . '/lib/Category/' . $driver . '.php';
+        } elseif (@file_exists(dirname(__FILE__) . '/Category/' . $driver . '.php')) {
+            include_once dirname(__FILE__) . '/Category/' . $driver . '.php';
+        } else {
+            @include_once 'Horde/Category/' . $driver . '.php';
+        }
         $class = 'Category_' . $driver;
         if (class_exists($class)) {
             return new $class($params);
         } else {
-            return false;
+            return PEAR::raiseError('Class definition of ' . $class . ' not found.');
         }
     }
 
@@ -133,14 +141,16 @@ class Category {
      * $driver. It will only create a new instance if no Category instance
      * with the same parameters currently exists.
      *
-     * This should be used if multiple permissions sources (and, thus,
+     * This should be used if multiple category sources (and, thus,
      * multiple Category instances) are required.
      *
      * This method must be invoked as: $var = &Category::singleton()
      *
-     * @param string $driver The type of concrete Category subclass to return.
+     * @param mixed $driver  The type of concrete Category subclass to return.
      *                       This is based on the storage driver ($driver). The
-     *                       code is dynamically included.
+     *                       code is dynamically included. If $driver is an array,
+     *                       then we will look in $driver[0]/lib/Category/ for
+     *                       the subclass implementation named $driver[1].php.
      * @param array  $params (optional) A hash containing any additional
      *                       configuration or connection parameters a subclass
      *                       might need.
@@ -153,7 +163,12 @@ class Category {
         static $instances;
         if (!isset($instances)) $instances = array();
 
-        $signature = md5(strtolower($driver) . '][' . implode('][', $params));
+        if (is_array($driver)) {
+            $drivertag = implode(':', $driver);
+        } else {
+            $drivertag = $driver;
+        }
+        $signature = md5(strtolower($drivertag) . '][' . implode('][', $params));
         if (!isset($instances[$signature])) {
             $instances[$signature] = &Category::factory($driver, $params);
         }
@@ -183,13 +198,13 @@ class Category {
 
         if ($this->exists($category, $parent)) {
             return new PEAR_Error('Already exists');
-        } elseif ($parent != '-1' && !isset($this->categories[$parent])) {
+        } elseif ($parent != '-1' && !isset($this->_categories[$parent])) {
             return new PEAR_Error('Add failed');
-        } elseif (!isset($this->categories[$category])) {
-            $this->categories[$category] = array();
+        } elseif (!isset($this->_categories[$category])) {
+            $this->_categories[$category] = array();
         }
 
-        $this->categories[$category][$parent] = true;
+        $this->_categories[$category][$parent] = true;
 
         return true;
     }
@@ -225,26 +240,26 @@ class Category {
 
         switch ($parent) {
         case '0':
-            unset($this->categories[$category]);
+            unset($this->_categories[$category]);
             break;
 
         case '-1':
-            if (!isset($this->categories[$category][$parent])) {
+            if (!isset($this->_categories[$category][$parent])) {
                 return new PEAR_Error('Does not exist');
             }
-            unset($this->categories[$category][$parent]);
+            unset($this->_categories[$category][$parent]);
             break;
 
         default:
-            if (!isset($this->categories[$category][$parent])) {
+            if (!isset($this->_categories[$category][$parent])) {
                 return new PEAR_Error('Does not exist');
             }
-            unset($this->categories[$category][$parent]);
+            unset($this->_categories[$category][$parent]);
         }
 
-        if (isset($this->categories[$category]) &&
-            count($this->categories[$category]) == 0) {
-            unset($this->categories[$category]);
+        if (isset($this->_categories[$category]) &&
+            count($this->_categories[$category]) == 0) {
+            unset($this->_categories[$category]);
         }
 
         return true;
@@ -253,10 +268,11 @@ class Category {
     /**
      * Move a category from one parent to a new one.
      *
-     * Note: there is no check against circular references.
      * @param string $category   The name of the category.
      * @param string $old_parent The name of the old parent.
      * @param string $new_parent The name of the new parent.
+     *
+     * @note There is no check against circular references.
      */
     function moveCategory($category, $old_parent, $new_parent)
     {
@@ -271,8 +287,8 @@ class Category {
             return new PEAR_Error('Does not exist');
         }
 
-        unset($this->categories[$category][$old_parent]);
-        $this->categories[$category][$new_parent] = true;
+        unset($this->_categories[$category][$old_parent]);
+        $this->_categories[$category][$new_parent] = true;
 
         return true;
     }
@@ -306,8 +322,8 @@ class Category {
             return new PEAR_Error('Duplicate name');
         }
 
-        $this->categories[$new_name] = $this->categories[$old_name];
-        unset($this->categories[$old_name]);
+        $this->_categories[$new_name] = $this->_categories[$old_name];
+        unset($this->_categories[$old_name]);
 
         return true;
     }
@@ -321,10 +337,11 @@ class Category {
      */
     function &getCategory($category, $class = 'CategoryObject')
     {
+        $this->_load($category);
         if (!class_exists($class)) {
             return PEAR::raiseError($class . ' not found');
         }
-        if (empty($this->categories[$category])) {
+        if (empty($this->_categories[$category])) {
             return PEAR::raiseError($category . ' not found');
         }
 
@@ -372,6 +389,7 @@ class Category {
      */
     function export($format, $parent = '-1')
     {
+        $this->_load($parent);
         $out = array();
 
         switch ($format) {
@@ -460,15 +478,24 @@ class Category {
     {
         switch ($format) {
         case CATEGORY_FORMAT_FETCH:
-            foreach ($data as $key1 => $val) {
-                $data2 = array();
-                foreach($val as $key => $val2) {
-                    $data2[$val2] = true;
+            $cats = array();
+            $cdata = array();
+            $cids = array();
+            foreach ($data as $cat) {
+                $cids[$cat[0]] = $cat[1];
+                $cats[$cat[1]] = $cat[2];
+            }
+            foreach ($cats as $cat => $parents) {
+                if (!empty($parents)) {
+                    $parents = explode(':', substr($parents, 1));
+                    $par = $parents[count($parents) - 1];
+                    $cdata[$cat] = array($cids[$par] => true);
+                } else {
+                    $cdata[$cat] = array('-1' => true);
                 }
-                $data[$key1] = $data2;
             }
 
-            $this->categories = array_merge_recursive($this->categories, $data);
+            $this->_categories = array_merge_recursive($this->_categories, $cdata);
             break;
 
         default:
@@ -510,7 +537,7 @@ class Category {
     function extractOneLevel($parent = '-1')
     {
         $out = array();
-        foreach ($this->categories as $category => $qparent) {
+        foreach ($this->_categories as $category => $qparent) {
             foreach ($qparent as $vparent => $notuse) {
                 if ($vparent == $parent) {
                     if (!isset($out[$parent])) $out[$parent] = array();
@@ -609,7 +636,7 @@ class Category {
             return new PEAR_Error('Does not exist');
         }
 
-        return $this->categories[$child];
+        return $this->_categories[$child];
     }
 
     /**
@@ -637,37 +664,45 @@ class Category {
     }
 
     /**
-     * Say if a category exists or not.
-     * The category -1 is always true
+     * Check if a category exists or not. The category -1 always
+     * exists.
      *
      * @param string $category The name of the category
-     * @param optional string $parent The name of the parent from where
-     *                                we want to check.
-     *                                0 means every parent
      *
-     * @return boolean true if the category exists, false otherwise.
+     * @return boolean  True if the category exists, false otherwise.
      */
-    function exists($category, $parent = '0')
+    function exists($category)
     {
+        $this->_load($category);
         if (is_subclass_of($category, 'CategoryObject')) {
             $category = $category->getName();
         }
         if ($category == '-1') {
             return true;
         }
-        if (!isset($this->categories[$category])) {
-            return false;
-        }
-        if ($parent == '0') {
-            return true;
-        }
-        if (!isset($this->categories[$category][$parent])) {
+        if (!array_key_exists($category, $this->_categories)) {
             return false;
         }
 
         return true;
     }
 
+    /**
+     * Load (a subset of) the category tree into the $_categories
+     * array.
+     *
+     * @param string $root  (optional) Which portion of the category
+     *                      tree to load. Defaults to all of it.
+     *
+     * @return mixed  True on success or a PEAR_Error on failure.
+     *
+     * @note No check against circular references.
+     * @access private
+     */
+    function _load($root = null)
+    {
+    }
+
 }
 
 /**
@@ -678,7 +713,7 @@ class Category {
  *
  * @author  Stephane Huther <shuther@bigfoot.com>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.8.2.6 $
+ * @version $Revision: 1.8.2.15 $
  * @since   Horde 2.1
  * @package horde.category
  */
