@@ -1,8 +1,10 @@
 <?php
-/**
- * $Horde: horde/lib/Category/sql.php,v 1.8.2.7 2002/04/05 01:24:27 jon Exp $
- * Copyright 1999, 2000, 2001, 2002 Stephane Huther <shuther@bigfoot.com>
- * Copyright 2001, 2002 Chuck Hagenbuch <chuck@horde.org>
+/*
+ * $Horde: horde/lib/Category/sql.php,v 1.8.2.16 2003/01/17 10:22:16 jan Exp $
+ *
+ * Copyright 1999-2003 Stephane Huther <shuther@bigfoot.com>
+ * Copyright 2001-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
  * See the enclosed file COPYING for license information (LGPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  */
@@ -19,8 +21,6 @@
  *      'password'       The password associated with 'username'.
  *      'database'       The name of the database.
  *      'table'          The name of the data table in 'database'.
- *      'tableRelations' The name of the relation parents/children table in
- *                      'database'.
  *
  * The table structure for the category system is as follows:
  *
@@ -30,7 +30,7 @@
  * undo/redo if possible
  *
  * @author  Stephane Huther <shuther@bigfoot.com>
- * @version $Revision: 1.8.2.7 $
+ * @version $Revision: 1.8.2.16 $
  * @since   Horde 2.1
  * @package horde.category
  *
@@ -40,9 +40,9 @@ class Category_sql extends Category {
 
     /**
      * Handle for the current database connection.
-     * @var resource $db
+     * @var resource $_db
      */
-    var $db;
+    var $_db;
 
     /**
      * Boolean indicating whether or not we're connected to the SQL server.
@@ -69,47 +69,38 @@ class Category_sql extends Category {
     function _connect()
     {
         if (!$this->_connected) {
-            if (!is_array($this->params)) {
+            if (!is_array($this->_params)) {
                 Horde::fatal(new PEAR_Error(_("No configuration information specified for SQL Categories.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['phptype'])) {
+            if (!isset($this->_params['phptype'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'phptype' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['hostspec'])) {
+            if (!isset($this->_params['hostspec'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'hostspec' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['username'])) {
+            if (!isset($this->_params['username'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'username' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['password'])) {
+            if (!isset($this->_params['password'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'password' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['database'])) {
+            if (!isset($this->_params['database'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'database' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['table'])) {
+            if (!isset($this->_params['table'])) {
                 Horde::fatal(new PEAR_Error(_("Required 'table' not specified in categories configuration.")), __FILE__, __LINE__);
             }
-            if (!isset($this->params['tableRelations'])) {
-                Horde::fatal(new PEAR_Error(_("Required 'tableRelations' not specified in categories configuration.")), __FILE__, __LINE__);
-            }
 
             /* Connect to the SQL server using the supplied parameters. */
             include_once 'DB.php';
-            $this->db = &DB::connect($this->params, true);
-            if (DB::isError($this->db) || DB::isWarning($this->db)) {
-                Horde::fatal($this->db, __FILE__, __LINE__);
+            $this->_db = &DB::connect($this->_params, true);
+            if (DB::isError($this->_db)) {
+                Horde::fatal($this->_db, __FILE__, __LINE__);
             }
 
             /* Enable the "portability" option. */
-            $this->db->setOption('optimize', 'portability');
-
+            $this->_db->setOption('optimize', 'portability');
             $this->_connected = true;
-
-            $r = $this->initialize(); // Load everything in memory.
-            if (PEAR::isError($r)) {
-                Horde::fatal($r, __FILE__, __LINE__);
-            }
         }
 
         return true;
@@ -124,50 +115,65 @@ class Category_sql extends Category {
     {
         if ($this->_connected) {
             $this->_connected = false;
-            return $this->db->disconnect();
+            return $this->_db->disconnect();
         }
 
         return true;
     }
 
     /**
-     * Dump the database to the array of this class
-     * it is a way to do a one way synchronize
+     * Load (a subset of) the category tree into the $_categories
+     * array.
      *
-     * @return mixed may return a DB error if not an array
+     * @param string $root  (optional) Which portion of the category
+     *                      tree to load. Defaults to all of it.
      *
-     * note: there is no check against circular reference!!!
+     * @return mixed  True on success or a PEAR_Error on failure.
+     *
+     * @note No check against circular references.
+     * @access private
      */
-    function initialize()
+    function _load($root = null)
     {
-        $query = sprintf('SELECT t.category_name as name, t2.category_name as category_id_parent FROM %s t, %s t2, %s cp' .
-                         ' WHERE t.group_uid=%s AND cp.category_id_parent=t2.category_id AND cp.category_id_child=t.category_id' .
-                         ' AND t2.group_uid=%s ',
-                         $this->params['table'], $this->params['table'], $this->params['tableRelations'],
-                         $this->db->quote($this->params['group']), $this->db->quote($this->params['group']));
+        // Do NOT use Category::exists() here; that would cause an
+        // infinite loop.
+        if (isset($this->_categories[$root]) ||
+            (count($this->_categories) > 0 && $root == '-1')) {
+            return true;
+        }
+        if (!empty($root) && $root != '-1') {
+            $root = $this->_db->getAssoc(sprintf('SELECT 0, category_id, category_parents FROM %s' .
+                                                 ' WHERE category_name = %s AND group_uid = %s',
+                                                 $this->_params['table'],
+                                                 $this->_db->quote($root),
+                                                 $this->_db->quote($this->_params['group'])));
+            if (count($root) == 0) {
+                return false;
+            }
 
-        /* Execute the query. */
-        $result = $this->db->getAssoc($query, true);
-
-        if (DB::isError($result)) {
-            return $result;
+            $pstring = $root[0][1] . ':' . $root[0][0] . '%';
+            if (!empty($root[0][1])) {
+                $ids = substr($root[0][1], 1);
+                $pquery = ' OR category_id in (' . str_replace(':', ', ', $ids) . ')';
+            } else {
+                $pquery = '';
+            }
+            $data = $this->_db->getAll(sprintf('SELECT category_id, category_name, category_parents FROM %s' .
+                                               ' WHERE (category_parents LIKE %s OR category_id = %s%s)'.
+                                               ' AND group_uid = %s',
+                                               $this->_params['table'],
+                                               $this->_db->quote($pstring),
+                                               $root[0][0],
+                                               $pquery,
+                                               $this->_db->quote($this->_params['group'])));
+        } else {
+            $data = $this->_db->getAll(sprintf('SELECT category_id, category_name, category_parents FROM %s' .
+                                              ' WHERE group_uid = %s',
+                                              $this->_params['table'],
+                                              $this->_db->quote($this->_params['group'])));
         }
 
-        $query = sprintf('SELECT t.category_name as name, \'-1\' as parent FROM %s t, %s cp' .
-                         ' WHERE t.group_uid=%s AND t.category_id=cp.category_id_child AND cp.category_id_parent=\'-1\'',
-                         $this->params['table'], $this->params['tableRelations'], $this->db->quote($this->params['group']));
-
-        /* Execute the query. */
-        $result2 = $this->db->getAssoc($query, true);
-
-        if (DB::isError($result2)) {
-            return $result2;
-        }
-
-        $this->import(CATEGORY_FORMAT_FETCH, $result);
-        $this->import(CATEGORY_FORMAT_FETCH, $result2);
-
-        return true;
+        return $this->import(CATEGORY_FORMAT_FETCH, $data);
     }
 
     /**
@@ -181,9 +187,9 @@ class Category_sql extends Category {
     {
         $this->_connect();
 
-        $retval = parent::addCategory($category, $parent);
-        if (PEAR::isError($retval)) {
-            return $retval;
+        $result = parent::addCategory($category, $parent);
+        if (PEAR::isError($result)) {
+            return $result;
         }
 
         if (is_subclass_of($category, 'CategoryObject')) {
@@ -196,45 +202,36 @@ class Category_sql extends Category {
             $ser = SERIALIZEUNIT_NONE;
         }
 
-        $id = $this->db->nextId($this->params['table']);
+        $id = $this->_db->nextId($this->_params['table']);
         if (DB::isError($id)) {
             return $id;
         }
 
         if ('-1' == $parent) {
-            $parentid = '-1';
+            $parents = '';
         } else {
-            $query = sprintf('SELECT t.category_id as id FROM %s t WHERE t.category_name=%s',
-                             $this->params['table'], $this->db->quote($parent));
-            $parentid = $this->db->getCol($query);
-            if (DB::isError($parentid)) {
-                return $parentid;
+            $parents = $this->_db->getAssoc(sprintf('SELECT 0, category_id, category_parents FROM %s WHERE category_name = %s',
+                                                    $this->_params['table'],
+                                                    $this->_db->quote($parent)));
+            if (DB::isError($parents)) {
+                return $parents;
             }
 
-            if (count($parentid) == 0) {
-                $parentid = '-1';
-            } else {
-                $parentid = $parentid[0];
-            }
+            $parents = $parents[0][1] . ':' . $parents[0][0];
         }
 
-        $query = sprintf('INSERT INTO %s (category_id, group_uid, category_name, category_data, user_uid, category_serialized)' .
-                         ' VALUES (%s, %s, %s, %s, %s, %s)',
-                         $this->params['table'], $id, $this->db->quote($this->params['group']),
-                         $this->db->quote($name), $this->db->quote($data),
-                         $this->db->quote(Auth::getAuth()), $ser);
+        $query = sprintf('INSERT INTO %s (category_id, group_uid, category_name, category_data, user_uid, category_serialized, category_parents)' .
+                         ' VALUES (%s, %s, %s, %s, %s, %s, %s)',
+                         $this->_params['table'],
+                         $id,
+                         $this->_db->quote($this->_params['group']),
+                         $this->_db->quote($name),
+                         $this->_db->quote($data),
+                         $this->_db->quote(Auth::getAuth()),
+                         $ser,
+                         $this->_db->quote($parents));
 
-        /* Execute the query. */
-        $result = $this->db->query($query);
-        if (DB::isError($result)) {
-            return $result;
-        }
-
-        $query = sprintf('INSERT INTO %s (category_id_child, category_id_parent) VALUES (%s, %s)',
-                         $this->params['tableRelations'], $id, $parentid);
-
-        /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
         if (DB::isError($result)) {
             return $result;
         }
@@ -257,9 +254,9 @@ class Category_sql extends Category {
     {
         $this->_connect();
 
-        $retval = parent::removeCategory($category, $parent);
-        if (PEAR::isError($retval)) {
-            return $retval;
+        $result = parent::removeCategory($category, $parent);
+        if (PEAR::isError($result)) {
+            return $result;
         }
 
         if (is_subclass_of($category, 'CategoryObject')) {
@@ -268,85 +265,67 @@ class Category_sql extends Category {
             $name = $category;
         }
 
-        if (in_array($name, array_values($this->categories))) {
-            return new PEAR_Error('Removal failed');
-        }
-
-        $query = sprintf('DELETE FROM %s WHERE group_uid=%s AND category_name=%s',
-                         $this->params['table'],
-                         $this->db->quote($this->params['group']),
-                         $this->db->quote($name));
+        $query = sprintf('DELETE FROM %s WHERE group_uid = %s AND category_name = %s',
+                         $this->_params['table'],
+                         $this->_db->quote($this->_params['group']),
+                         $this->_db->quote($name));
 
         /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
         if (DB::isError($result)) {
             return $result;
         }
 
+        if ($this->exists($name)) {
+            return new PEAR_Error('Removal failed');
+        }
+
         return true;
     }
 
     /**
      * Move a category from one parent to a new one.
      *
-     * note: there is no check against circular reference!!!
      * @param string $name       The name of the category.
+     * @param string $old_parent The name of the old parent.
      * @param string $new_parent The name of the new parent.
+     *
+     * @note There is no check against circular references.
      */
     function moveCategory($name, $old_parent, $new_parent = '-1')
     {
         $this->_connect();
 
-        $ret = parent::moveCategory($name, $old_parent, $new_parent);
-        if (PEAR::isError($ret)) {
-            return $ret;
+        $result = parent::moveCategory($name, $old_parent, $new_parent);
+        if (PEAR::isError($result)) {
+            return $result;
         }
 
-        if (is_subclass_of($name, 'CategoryObject')) {
-            $name = SerializeUnit::serializeUnit($name->getData(), CATEGORY_SERIALIZE_FORMAT);
-            $ser = CATEGORY_SERIALIZE_FORMAT;
+        if (is_subclass_of($category, 'CategoryObject')) {
+            $name = $category->getName();
         } else {
-            $ser = SERIALIZEUNIT_NONE;
+            $name = $category;
         }
 
         if ('-1' == $new_parent) {
-            $parentid = '-1';
+            $new_parents = '';
         } else {
-            $query = sprintf('SELECT t.category_id as id FROM %s t WHERE t.category_name=%s AND t.group_uid=%s',
-                             $this->params['table'], $this->db->quote($new_parent),
-                             $this->db->quote($this->params['group']));
-            $parentid = $this->db->getCol($query);
-            if (DB::isError($parentid)) {
-                return $parentid;
-            }
-            if ('0' == $parentid) {
-                $parentid = '-1';
-            } else {
-                $parentid = $parentid[0];
+            $new_parents = $this->_db->getAssoc(sprintf('SELECT 0, category_id, category_parents FROM %s WHERE category_name = %s',
+                                                        $this->_params['table'],
+                                                        $this->_db->quote($new_parent)));
+            if (DB::isError($new_parents)) {
+                return $new_parents;
             }
+
+            $new_parents = $new_parents[0][1] . ':' . $new_parents[0][0];
         }
 
-        $query = sprintf('SELECT cp.category_id_child as child, cp.category_id_parent as parent FROM %s cp, %s t, %s told' .
-                         ' WHERE t.group_uid=%s AND t.category_name=%s AND t.category_serialized=%s' .
-                         ' AND t.category_id=cp.category_id_child AND cp.category_id_parent=told.category_id' .
-                         ' AND t.group_uid=told.group_uid AND told.category_name=%s',
-                         $this->params['tableRelations'], $this->params['table'],
-                         $this->params['table'], $this->db->quote($this->params['group']),
-                         $this->db->quote($name), $ser, $this->db->quote($old_parent));
+        $query = sprintf('UPDATE %s SET category_parents = %s WHERE category_name = %s',
+                         $this->_params['table'],
+                         $this->_db->quote($new_parents),
+                         $this->_db->quote($name));
 
-        $row = $this->db->getRow($query, array(), DB_FETCHMODE_ASSOC);
-        if (DB::isError($row)) {
-            return $row;
-        }
-
-        $old_parentid = $row['parent'];
-        $childid = $row['child'];
-
-        $query = sprintf('UPDATE %s SET category_id_parent=%s WHERE category_id_child=%s AND category_id_parent=%s',
-                         $this->params['tableRelations'], $parentid, $childid, $old_parentid);
-
-        /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
         if (DB::isError($result)) {
             return $result;
         }
@@ -364,9 +343,9 @@ class Category_sql extends Category {
     {
         $this->_connect();
 
-        $retval = parent::renameCategory($old_category, $new_category);
-        if (PEAR::isError($retval)) {
-            return $retval;
+        $result = parent::renameCategory($old_category, $new_category);
+        if (PEAR::isError($result)) {
+            return $result;
         }
 
         if (is_subclass_of($old_category, 'CategoryObject')) {
@@ -381,12 +360,13 @@ class Category_sql extends Category {
             $new_name = $new_category;
         }
 
-        $query = sprintf('UPDATE %s SET category_name=%s' .
-                         ' WHERE category_name=%s',
-                         $this->params['table'], $this->db->quote($new_name), $this->db->quote($old_name));
+        $query = sprintf('UPDATE %s SET category_name = %s' .
+                         ' WHERE category_name = %s',
+                         $this->_params['table'],
+                         $this->_db->quote($new_name),
+                         $this->_db->quote($old_name));
 
-        /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
         if (DB::isError($result)) {
             return $result;
         }
@@ -399,10 +379,10 @@ class Category_sql extends Category {
         $this->_connect();
 
         $query = sprintf('SELECT category_data FROM %s WHERE category_name = %s',
-                         $this->params['table'], $this->db->quote($category));
+                         $this->_params['table'],
+                         $this->_db->quote($category));
 
-        /* Execute the query. */
-        return SerializeUnit::unSerializeUnit($this->db->getOne($query), CATEGORY_SERIALIZE_FORMAT);
+        return SerializeUnit::unSerializeUnit($this->_db->getOne($query), CATEGORY_SERIALIZE_FORMAT);
     }
 
     /**
@@ -415,9 +395,9 @@ class Category_sql extends Category {
     {
         $this->_connect();
 
-        $retval = parent::updateCategoryData($category);
-        if (PEAR::isError($retval)) {
-            return $retval;
+        $result = parent::updateCategoryData($category);
+        if (PEAR::isError($result)) {
+            return $result;
         }
 
         if (!is_subclass_of($category, 'CategoryObject')) {
@@ -429,13 +409,14 @@ class Category_sql extends Category {
         $data = SerializeUnit::serializeUnit($category->getData(), CATEGORY_SERIALIZE_FORMAT);
         $ser = CATEGORY_SERIALIZE_FORMAT;
 
-        $query = sprintf('UPDATE %s SET category_data=%s, category_serialized=%s' .
-                         ' WHERE category_name=%s',
-                         $this->params['table'], $this->db->quote($data),
-                         $this->db->quote($ser), $this->db->quote($name));
+        $query = sprintf('UPDATE %s SET category_data = %s, category_serialized = %s' .
+                         ' WHERE category_name = %s',
+                         $this->_params['table'],
+                         $this->_db->quote($data),
+                         $this->_db->quote($ser),
+                         $this->_db->quote($name));
 
-        /* Execute the query. */
-        $result = $this->db->query($query);
+        $result = $this->_db->query($query);
         if (DB::isError($result)) {
             return $result;
         }
