@@ -4,7 +4,7 @@
  * The Cipher_blowfish:: class implements the Cipher interface enryption data
  * using the Blowfish algorithm.
  *
- * $Horde: horde/lib/Cipher/blowfish.php,v 1.2.2.3 2003/01/03 13:23:22 jan Exp $
+ * $Horde: horde/lib/Cipher/blowfish.php,v 1.2.2.4 2003/04/12 20:50:40 slusarz Exp $
  *
  * Copyright 2002-2003 Mike Cochrane <mike@graftonhall.co.nz>
  *
@@ -12,7 +12,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 1.2.2.3 $
+ * @version $Revision: 1.2.2.4 $
  * @since   Horde 2.2
  * @package horde.cipher
  */
@@ -304,57 +304,53 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
     function setKey($key)
     {
         $key = $this->_formatKey($key);
-        $keyPos = 0;
-        $keyXor = 0;
-        for ($i = 0; $i < count($this->p); $i++) {
+        $keyPos = $keyXor = 0;
+
+        $iMax = count($this->p);
+        $keyLen = count($key);
+        for ($i = 0; $i < $iMax; $i++) {
             for ($t = 0; $t < 4; $t++) {
                 $keyXor = ($keyXor << 8) | (($key[$keyPos]) & 0x0ff);
-                if (++$keyPos == count($key)) {
+                if (++$keyPos == $keyLen) {
                     $keyPos = 0;
                 }
             }
             $this->p[$i] = $this->p[$i] ^ $keyXor;
         }
 
-        $encZero = "\0\0\0\0\0\0\0\0";
-        for ($i = 0; $i + 1 < count($this->p); $i+=2) {
-          $encZero = $this->encryptBlock($encZero);
-          $unpacked = unpack("Nhi", substr($encZero, 0 ,4));
-          $this->p[$i]     = $unpacked['hi'];
-          $unpacked = unpack("Nlo", substr($encZero, 4 ,4));
-          $this->p[$i + 1] = $unpacked['lo'];
+        $encZero = array('L' => 0, 'R' => 0);
+        for ($i = 0; $i + 1 < $iMax; $i += 2) {
+          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+          $this->p[$i] = $encZero['L'];
+          $this->p[$i + 1] = $encZero['R'];
         }
 
-        for ($i = 0; $i < count($this->s1); $i+=2) {
-          $encZero = $this->encryptBlock($encZero);
-          $unpacked = unpack("Nhi", substr($encZero, 0 ,4));
-          $this->s1[$i]     = $unpacked['hi'];
-          $unpacked = unpack("Nlo", substr($encZero, 4 ,4));
-          $this->s1[$i + 1] = $unpacked['lo'];
+        $iMax = count($this->s1);
+        for ($i = 0; $i < $iMax; $i += 2) {
+          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+          $this->s1[$i] = $encZero['L'];
+          $this->s1[$i + 1] = $encZero['R'];
         }
 
-        for ($i = 0; $i < count($this->s2); $i+=2) {
-          $encZero = $this->encryptBlock($encZero);
-          $unpacked = unpack("Nhi", substr($encZero, 0 ,4));
-          $this->s2[$i]     = $unpacked['hi'];
-          $unpacked = unpack("Nlo", substr($encZero, 4 ,4));
-          $this->s2[$i + 1] = $unpacked['lo'];
+        $iMax = count($this->s2);
+        for ($i = 0; $i < $iMax; $i += 2) {
+          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+          $this->s2[$i] = $encZero['L'];
+          $this->s2[$i + 1] = $encZero['R'];
         }
 
-        for ($i = 0; $i < count($this->s3); $i+=2) {
-          $encZero = $this->encryptBlock($encZero);
-          $unpacked = unpack("Nhi", substr($encZero, 0 ,4));
-          $this->s3[$i]     = $unpacked['hi'];
-          $unpacked = unpack("Nlo", substr($encZero, 4 ,4));
-          $this->s3[$i + 1] = $unpacked['lo'];
+        $iMax = count($this->s3);
+        for ($i = 0; $i < $iMax; $i += 2) {
+          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+          $this->s3[$i] = $encZero['L'];
+          $this->s3[$i + 1] = $encZero['R'];
         }
 
-        for ($i = 0; $i < count($this->s4); $i+=2) {
-          $encZero = $this->encryptBlock($encZero);
-          $unpacked = unpack("Nhi", substr($encZero, 0 ,4));
-          $this->s4[$i]     = $unpacked['hi'];
-          $unpacked = unpack("Nlo", substr($encZero, 4 ,4));
-          $this->s4[$i + 1] = $unpacked['lo'];
+        $iMax = count($this->s4);
+        for ($i = 0; $i < $iMax; $i += 2) {
+          $encZero = $this->_encryptBlock($encZero['L'], $encZero['R']);
+          $this->s4[$i] = $encZero['L'];
+          $this->s4[$i + 1] = $encZero['R'];
         }
 
     }
@@ -383,9 +379,21 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
             $this->setKey($key);
         }
 
-        $L = $this->_formatData(substr($block, 0, 4));
-        $R = $this->_formatData(substr($block, 4, 4));
-
+        list($L, $R) = array_values(unpack('N*', $block));
+        $parts = $this->_encryptBlock($L, $R);
+        return pack("NN", $parts['L'], $parts['R']);
+    }
+    
+    /**
+     * Encrypt a block on data.
+     *
+     * @param String $L  The data to encrypt.
+     * @param String $R  The data to encrypt.
+     *
+     * @return String  The encrypted output.
+     */
+    function _encryptBlock($L, $R)
+    {
         $L ^= $this->p[0];
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[1];
         $L ^= ((($this->s1[($R >> 24) & 0xFF] + $this->s2[($R >> 16) & 0x0ff]) ^ $this->s3[($R >> 8) & 0x0ff]) + $this->s4[$R & 0x0ff]) ^ $this->p[2];
@@ -403,9 +411,9 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
         $L ^= ((($this->s1[($R >> 24) & 0xFF] + $this->s2[($R >> 16) & 0x0ff]) ^ $this->s3[($R >> 8) & 0x0ff]) + $this->s4[$R & 0x0ff]) ^ $this->p[14];
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[15];
         $L ^= ((($this->s1[($R >> 24) & 0xFF] + $this->s2[($R >> 16) & 0x0ff]) ^ $this->s3[($R >> 8) & 0x0ff]) + $this->s4[$R & 0x0ff]) ^ $this->p[16];
+        $R ^= $this->p[17];
 
-        $encrypted = pack("N", $R ^ $this->p[17]) . pack("N", $L);
-        return $encrypted;
+        return array('L' => $R, 'R' => $L);
     }
 
     /**
@@ -422,9 +430,7 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
             $this->setKey($key);
         }
 
-        $block = str_pad($block, 8, '\0');
-        $L = $this->_formatData(substr($block, 0, 4));
-        $R = $this->_formatData(substr($block, 4, 4));
+        list($L, $R) = array_values(unpack('N*', $block));
 
         $L ^= $this->p[17];
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[16];
@@ -444,55 +450,18 @@ class Horde_Cipher_blowfish extends Horde_Cipher {
         $R ^= ((($this->s1[($L >> 24) & 0xFF] + $this->s2[($L >> 16) & 0x0ff]) ^ $this->s3[($L >> 8) & 0x0ff]) + $this->s4[$L & 0x0ff]) ^ $this->p[2];
         $L ^= ((($this->s1[($R >> 24) & 0xFF] + $this->s2[($R >> 16) & 0x0ff]) ^ $this->s3[($R >> 8) & 0x0ff]) + $this->s4[$R & 0x0ff]) ^ $this->p[1];
 
-        $decrypted = pack("N", $R ^ $this->p[0]) . pack("N", $L);
+        $decrypted = pack("NN", $R ^ $this->p[0], $L);
         return $decrypted;
     }
 
     /**
-     * Convert a string into a array of the ordinates
-     * of it's characters
+     * Converts a text key into an array.
      *
-     * @return array    The data
-     */
-    function _formatData($data)
-    {
-        return $this->_combine4(unpack('C*', $data), 0x1);
-    }
-
-    /**
-     * Converts a text key into an array
-     *
-     * @return array    The key
+     * @return array  The key.
      */
     function _formatKey($key)
     {
         return array_values(unpack('C*', $key));
     }
 
-    /**
-     * Pack four 8 bit values into one 32 bit values
-     *
-     * @param Array $key        Array of 8 bit values.
-     * @param Integer $start    Start position in array to get 4 values from.
-     *
-     * @return Interget         32 bit value.
-     */
-    function _combine4($key, $start = 0)
-    {
-        $res = 0;
-        if (array_key_exists($start, $key)) {
-            $res |= ($key[$start]) << 24;
-        }
-        if (array_key_exists($start + 1, $key)) {
-            $res |= ($key[$start + 1]) << 16;
-        }
-        if (array_key_exists($start + 2, $key)) {
-            $res |= ($key[$start + 2]) << 8;
-        }
-        if (array_key_exists($start + 3, $key)) {
-            $res |= ($key[$start + 3]);
-        }
-        return $res;
-    }
-
 }
