@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Horde.php,v 1.118.2.42 2003/04/23 21:43:06 jan Exp $
+ * $Horde: horde/lib/Horde.php,v 1.118.2.56 2004/10/25 15:59:15 chuck Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -120,7 +120,7 @@ function _fileCleanup($filename = false, $register = true)
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.118.2.42 $
+ * @version $Revision: 1.118.2.56 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -184,8 +184,8 @@ class Horde {
         }
 
         include_once 'Log.php';
-        $logger = Log::singleton($conf['log']['type'], $conf['log']['name'],
-                                 $conf['log']['ident'], $conf['log']['params']);
+        $logger = &Log::singleton($conf['log']['type'], $conf['log']['name'],
+                                  $conf['log']['ident'], $conf['log']['params']);
 
         if (!$logger) {
             Horde::fatal(new PEAR_Error('An error has occurred. Furthermore, Horde encountered an error attempting to log this error. Please check your Horde logging configuration in horde/config/horde.php.'), __FILE__, __LINE__, false);
@@ -205,7 +205,15 @@ class Horde {
         $app = array_key_exists('registry', $GLOBALS) ? $GLOBALS['registry']->getApp() : 'horde';
         $message = '[' . $app . '] ' . $message . ' [on line ' . $line . ' of "' . $file . '"]';
 
+        /* Make sure to log in the system's locale. */
+        $locale = setlocale(LC_TIME, 0);
+        setlocale(LC_TIME, 'C');
+
         $logger->log($message, $priority);
+
+        /* Restore original locale. */
+        setlocale(LC_TIME, $locale);
+
         return true;
     }
 
@@ -584,7 +592,7 @@ HTML;
         $img .= ' border="0"';
         if (!empty($attr)) {
             $img .= ' ' . $attr;
-            if (preg_match('/alt=([\'"])([^\1]*)\1/i', $attr, $match)) {
+            if (preg_match('/alt=([\'"])(.*?)\1/i', $attr, $match)) {
                 $img .= ' title="'. $match[2] . '"';
             }
         }
@@ -849,31 +857,65 @@ HTML;
             return;
         }
 
-        global $browser, $conf;
-
         /* Netscape =< 4 is so buggy with compression that we just turn it
            completely off for those browsers. */
-        if ($conf['compress_pages'] &&
+        if ($GLOBALS['conf']['compress_pages'] &&
             (ini_get('zlib.output_compression') != 1) &&
-            (($browser->getBrowser() != 'mozilla') ||
-             ($browser->getMajor() > 4))) {
-            /* Compress output if requested. */
+            (ini_get('output_handler') != 'ob_gzhandler') &&
+            (($GLOBALS['browser']->getBrowser() != 'mozilla') ||
+             ($GLOBALS['browser']->getMajor() > 4))) {
+            if (function_exists('ob_get_level') && ob_get_level()) {
+                ob_end_clean();
+            }
             ob_start('ob_gzhandler');
         }
 
         $started = true;
     }
 
+    /**
+     * Destroy any existing session on login and make sure to use a
+     * new session ID, to avoid session fixation issues. Should be
+     * called before checking a login.
+     */
+    function getCleanSession()
+    {
+        // Make sure to force a completely new session ID and clear
+        // all session data.
+        if (version_compare(phpversion(), '4.3.3') !== -1) {
+            session_regenerate_id();
+            session_unset();
+        } else {
+            @session_destroy();
+            if (function_exists('posix_getpid')) {
+                $new_session_id = md5(microtime() . posix_getpid());
+            } else {
+                $new_session_id = md5(uniqid(mt_rand(), true));
+            }
+            session_id($new_session_id);
+
+            // Restart the session, including setting up the session
+            // handler.
+            Horde::setupSessionHandler();
+            @session_start();
+        }
+    }
+
     /**
      * If there is a custom session handler, set it up now.
      *
      * @access public
      *
-     * @since Horde 2.3
+     * @since Horde 2.2.4
      */
     function setupSessionHandler()
     {
-        global $conf;
+        global $conf, $registry;
+
+        ini_set('session.use_trans_sid', 0);
+        session_set_cookie_params($conf['session_timeout'], $registry->getParam('cookie_path', 'horde'), $registry->getParam('cookie_domain', 'horde'));
+        session_name(urlencode($conf['session_name']));
+        session_cache_limiter($conf['cache_limiter']);
 
         $type = !empty($conf['sessionhandler']['type']) ? $conf['sessionhandler']['type'] : 'none';
 
@@ -905,4 +947,3 @@ HTML;
     }
 
 }
-?>
