@@ -1,13 +1,18 @@
 <?php
-// $Horde: horde/lib/Identity.php,v 1.4.2.8 2002/04/29 23:32:10 jan Exp $
-
-/**
+/*
+ * $Horde: horde/lib/Identity.php,v 1.4.2.13 2003/04/28 19:59:07 jan Exp $
+ *
+ * Copyright 2001-2003 Jan Schneider <jan@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
  * This class provides an interface to all identities a user might
  * have. Its methods take care of any site-specific restrictions
  * configured in prefs.php and conf.php.
  *
- * @author  Jan Schneider <jan@ammma.de>
- * @version $Revision: 1.4.2.8 $
+ * @author  Jan Schneider <jan@horde.org>
+ * @version $Revision: 1.4.2.13 $
  * @since   Horde 1.3.5
  * @package horde.identity
  */
@@ -34,21 +39,40 @@ class Identity {
      */
     var $properties = array();
 
+    /**
+     * Reference to the prefs object that this Identity points to.
+     * @var object Prefs $prefs
+     */
+    var $prefs;
+
     /**
      * Reads all the user's identities from the prefs object or builds
      * a new identity from the standard values given in prefs.php.
+     *
+     * @param optional string $user  If specified, we read another user's
+     *                               identities instead of the current user.
      */
-    function Identity()
+    function Identity($user = null)
     {
-        global $prefs;
+        if (is_null($user)) {
+            $this->prefs = &$GLOBALS['prefs'];
+            $this->default = $this->prefs->getValue('default_identity');
+            $this->identities = @unserialize($this->prefs->getValue('identities'));
+        } else {
+            global $registry;
+            $this->prefs = &Prefs::singleton($GLOBALS['conf']['prefs']['driver'], $registry->getApp(), '', '', $GLOBALS['conf']['prefs']['params']);
+            $this->prefs->setDefaults($registry->getParam('fileroot', 'horde') . '/config/prefs.php');
+            $this->prefs->setDefaults($registry->getParam('fileroot') . '/config/prefs.php');
 
-        $this->default = $prefs->getValue('default_identity');
-        $this->identities = @unserialize($prefs->getValue('identities'));
+            $vals = $this->prefs->getPref($user, array('default_identity', 'identities'));
+            $this->default = isset($vals['default_identity']) ? $vals['default_identity'] : 0;
+            $this->identities = @unserialize($vals['identities']);
+        }
 
         if (!is_array($this->identities) || (count($this->identities) <= 0)) {
             $identity = array('id' => _("Default Identity"));
             foreach ($this->properties as $key) {
-                $identity[$key] = $prefs->getValue($key);
+                $identity[$key] = $this->prefs->getValue($key);
             }
 
             $this->identities[] = $identity;
@@ -60,11 +84,9 @@ class Identity {
      */
     function save()
     {
-        global $prefs;
-
-        $prefs->setValue('identities', serialize($this->identities));
-        $prefs->setValue('default_identity', $this->default);
-        $prefs->store();
+        $this->prefs->setValue('identities', serialize($this->identities));
+        $this->prefs->setValue('default_identity', $this->default);
+        $this->prefs->store();
     }
 
     /**
@@ -129,14 +151,12 @@ class Identity {
      */
     function getValue($key, $identity = null)
     {
-        global $prefs;
-
         if (!isset($identity) || !isset($this->identities[$identity])) {
             $identity = $this->default;
         }
 
-        if (!isset($this->identities[$identity][$key]) || $prefs->isLocked($key)) {
-            $val = $prefs->getValue($key);
+        if (!isset($this->identities[$identity][$key]) || $this->prefs->isLocked($key)) {
+            $val = $this->prefs->getValue($key);
         } else {
             $val = $this->identities[$identity][$key];
         }
@@ -169,13 +189,11 @@ class Identity {
      */
     function setValue($key, $val, $identity = null)
     {
-        global $prefs;
-
         if (!isset($identity)) {
             $identity = $this->default;
         }
 
-        if (!$prefs->isLocked($key)) {
+        if (!$this->prefs->isLocked($key)) {
             $this->identities[$identity][$key] = $val;
             return true;
         } else {
@@ -190,10 +208,8 @@ class Identity {
      */
     function isLocked()
     {
-        global $prefs;
-
         foreach ($this->properties as $key) {
-            if (!$prefs->isLocked($key)) {
+            if (!$this->prefs->isLocked($key)) {
                 return false;
             }
         }
@@ -221,4 +237,3 @@ class Identity {
     }
 
 }
-?>
