@@ -1,5 +1,5 @@
 <?php
-// $Horde: horde/lib/Lang.php,v 1.13.2.8 2002/04/14 16:24:37 jan Exp $
+// $Horde: horde/lib/Lang.php,v 1.13.2.14 2003/01/17 10:22:14 jan Exp $
 
 /**
  * The Lang:: class provides common methods for handling language detection
@@ -7,7 +7,7 @@
  *
  * @author  Jon Parise <jon@horde.org>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.13.2.8 $
+ * @version $Revision: 1.13.2.14 $
  * @since   Horde 1.3
  * @package horde
  */
@@ -21,22 +21,25 @@ class Lang {
      */
     function select()
     {
-        global $HTTP_SERVER_VARS, $HTTP_SESSION_VARS, $nls;
+        global $nls, $prefs;
 
-        /* First see if the user selected a language from the login screen */
         $lang = Horde::getFormData('new_lang');
-        if (!empty($lang)) {
-            $language = $lang;
 
+        /* First, check if language pref is locked and if so set it to its value */
+        if (isset($prefs) && $prefs->isLocked('language')) {
+            $language = $prefs->getValue('language');
+        /* Check if the user selected a language from the login screen */
+        } elseif (!empty($lang)) {
+            $language = $lang;
         /* Check if we have a language set in a cookie */
-        } elseif (isset($HTTP_SESSION_VARS['horde_language'])) {
-            $language = $HTTP_SESSION_VARS['horde_language'];
+        } elseif (isset($_SESSION['horde_language'])) {
+            $language = $_SESSION['horde_language'];
 
         /* Try browser-accepted languages, then default. */
-        } elseif (isset($HTTP_SERVER_VARS['HTTP_ACCEPT_LANGUAGE'])) {
+        } elseif (!empty($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
 
             /* The browser supplies a list, so return the first valid one. */
-            $browser_langs = explode(',', $HTTP_SERVER_VARS['HTTP_ACCEPT_LANGUAGE']);
+            $browser_langs = explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']);
             foreach ($browser_langs as $lang) {
                 $lang = Lang::_map(trim($lang));
                 if (Lang::isValid($lang)) {
@@ -86,6 +89,8 @@ class Lang {
      * @param string $directory     The directory where the application's
      *                              LC_MESSAGES directory resides
      * @param string $charset       The charset
+     *
+     * @since Horde 2.1
      */
     function setTextdomain($app, $directory, $charset)
     {
@@ -99,6 +104,17 @@ class Lang {
         }
     }
 
+    /**
+     * Alias for Lang::setTextdomain().
+     *
+     * @deprecated since Horde 2.1. Replaced by Lang::setTextdomain().
+     * @see Lang::setTextdomain()
+     */
+    function setDomain($app, $directory, $charset)
+    {
+        Lang::setTextdomain($app, $directory, $charset);
+    }
+
     /**
      * Determines whether the supplied language is valid.
      *
@@ -154,6 +170,8 @@ class Lang {
      *
      * @return string The character set that should be used with the
      * current locale settings.
+     *
+     * @since Horde 2.1
      */
     function getCharset()
     {
@@ -161,4 +179,3 @@ class Lang {
     }
 
 }
-?>
