@@ -1,12 +1,19 @@
 <?php
-// $Horde: horde/lib/MIME/Part.php,v 1.11.2.5 2002/04/18 00:29:34 jan Exp $
+/*
+ * $Horde: horde/lib/MIME/Part.php,v 1.11.2.9 2003/01/03 12:48:24 jan Exp $
+ *
+ * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The MIME_Part:: class provides a wrapper around MIME parts and methods
  * for dealing with them.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.11.2.5 $
+ * @version $Revision: 1.11.2.9 $
  * @since   Horde 1.3
  * @package horde.mime
  */
@@ -72,6 +79,9 @@ class MIME_Part {
         list($this->type, $this->subtype) = explode('/', strtolower($mimetype));
     }
 
+    /*
+     * @since Horde 2.1
+     */
     function setDisposition($disposition)
     {
         $this->disposition = $disposition;
@@ -200,13 +210,13 @@ class MIME_Part {
             && imap_8bit($text) != $text) {
             $this->transferEncoding = '8bit';
 
-            global $language, $nls, $HTTP_SERVER_VARS;
+            global $language, $nls;
 
             if (empty($this->charset)) {
                 if (!empty($nls['charsets'][$language])) {
                     $this->charset = $nls['charsets'][$language];
-                } else if (!empty($HTTP_SERVER_VARS['HTTP_ACCEPT_CHARSET'])) {
-                    $charsets = explode(',', $HTTP_SERVER_VARS['HTTP_ACCEPT_CHARSET']);
+                } else if (!empty($_SERVER['HTTP_ACCEPT_CHARSET'])) {
+                    $charsets = explode(',', $_SERVER['HTTP_ACCEPT_CHARSET']);
                     if (!empty($charsets[0])) {
                         $this->charset = trim($charsets[0]);
                     }
