@@ -1,12 +1,19 @@
 <?php
-// $Horde: horde/lib/MIME/Viewer/enscript.php,v 1.7.2.4 2002/04/08 22:43:17 jan Exp $
+/*
+ * $Horde: horde/lib/MIME/Viewer/enscript.php,v 1.7.2.8 2003/01/03 12:48:27 jan Exp $
+ *
+ * Copyright 1999-2003 Anil Madhavapeddy <anil@recoil.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The MIME_Viewer_enscript class renders out various content
  * in HTML format by using GNU Enscript.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.7.2.4 $
+ * @version $Revision: 1.7.2.8 $
  * @since   Horde 1.3
  * @package horde.mime.viewer
  */
@@ -22,6 +29,11 @@ class MIME_Viewer_enscript extends MIME_Viewer {
     {
         global $mime_drivers;
 
+        /* Check to make sure the program actually exists. */
+        if (file_exists($mime_drivers['horde']['enscript']['location']) === false) {
+            return '<pre>' . sprintf(_("The program used to view this message type (%s) was not found on the system."), $mime_drivers['horde']['enscript']['location']) . '</pre>';
+        }
+
         /* Create temporary files for both input and output to
          * Enscript. Note that we cannot use a pipe, since enscript
          * must have access to the whole file to determine its type
@@ -37,14 +49,9 @@ class MIME_Viewer_enscript extends MIME_Viewer {
 
         /* Execute the enscript command */
         include_once HORDE_BASE . '/lib/MIME/Magic.php';
-        $lang = $this->extensionToLang(MIME_Magic::MIMEToExt($this->mime_part->getType()));
-        exec(escapeShellCmd($mime_drivers['horde']['enscript']['location'] . " -E$lang --color -Whtml -p$tmpout $tmpin"));
-        $fin = fopen($tmpout, 'r');
-        $results = '';
-        while ($chunk = fread($fin, 4096)) {
-            $results .= $chunk;
-        }
-
+        $lang = escapeshellarg($this->extensionToLang(MIME_Magic::MIMEToExt($this->mime_part->getType())));
+        exec($mime_drivers['horde']['enscript']['location'] . " -E$lang --language=html --color --output=$tmpout < $tmpin");
+        $results = implode('', file($tmpout));
         /* Strip out the extraneous HTML from Enscript, and output it.
          * TODO: figure out why this doesn't work with preg_replace! - avsm */
         $res_arr = preg_split('/\<\/?PRE\>/', $results);
