@@ -1,12 +1,19 @@
 <?php
-// $Horde: horde/lib/MIME/Viewer/mspowerpoint.php,v 1.3.2.1 2001/12/23 20:19:07 chuck Exp $
+/*
+ * $Horde: horde/lib/MIME/Viewer/mspowerpoint.php,v 1.3.2.4 2003/01/03 12:48:27 jan Exp $
+ *
+ * Copyright 1999-2003 Anil Madhavapeddy <anil@recoil.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The MIME_Viewer_mspowerpoint class renders out Microsoft Powerpoint
  * documents in HTML format by using the xlHtml package.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.3.2.1 $
+ * @version $Revision: 1.3.2.4 $
  * @since   Horde 1.3
  * @package horde.mime.viewer
  */
@@ -22,6 +29,11 @@ class MIME_Viewer_mspowerpoint extends MIME_Viewer {
     {
         global $mime_drivers;
 
+        /* Check to make sure the program actually exists. */
+        if (file_exists($mime_drivers['horde']['mspowerpoint']['location']) === false) {
+            return '<pre>' . sprintf(_("The program used to view this message type (%s) was not found on the system."), $mime_drivers['horde']['mspowerpoint']['location']) . '</pre>';
+        }
+
         $tmp_ppt = Horde::getTempFile('horde_mspowerpoint');
 
         $fh = fopen($tmp_ppt, 'w');
