@@ -1,12 +1,19 @@
 <?php
-// $Horde: horde/lib/MIME/Viewer/tgz.php,v 1.10.2.3 2002/01/09 13:52:25 jan Exp $
+/*
+ * $Horde: horde/lib/MIME/Viewer/tgz.php,v 1.10.2.6 2003/01/03 12:48:28 jan Exp $
+ *
+ * Copyright 1999-2003 Anil Madhavapeddy <anil@recoil.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ */
 
 /**
  * The MIME_Viewer_tgz class renders out plain or gzipped tarballs in
  * HTML format by executing tar in query mode.
  *
  * @author  Anil Madhavapeddy <anil@recoil.org>
- * @version $Revision: 1.10.2.3 $
+ * @version $Revision: 1.10.2.6 $
  * @since   Horde 1.3
  * @package horde.mime.viewer
  */
@@ -23,6 +30,11 @@ class MIME_Viewer_tgz extends MIME_Viewer {
     {
         global $mime_drivers;
 
+        /* Check to make sure the program actually exists. */
+        if (file_exists($mime_drivers['horde']['tgz']['location']) === false) {
+            return '<pre>' . sprintf(_("The program used to view this message type (%s) was not found on the system."), $mime_drivers['horde']['tgz']['location']) . '</pre>';
+        }
+
         $tmp_tgz = Horde::getTempFile('hordetgz');
 
         $fh = fopen($tmp_tgz, 'w');
