@@ -1,20 +1,18 @@
 <?php
-/*
- * $Horde: horde/lib/PrefsUI.php,v 1.2.2.7 2003/01/03 12:48:36 jan Exp $
- *
- * Copyright 2002-2003
- *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
- */
-
-
 /**
  * Class for auto-generating the preferences user interface and
  * processing the forms.
  *
+ *
+ * $Horde: horde/lib/PrefsUI.php,v 1.2.2.8 2003/02/18 00:07:56 jan Exp $
+ *
+ * Copyright 2002-2003 Chuck Hagenbuch <chuck@horde.org>
+ *
+ * See the enclosed file COPYING for license information (LGPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.2.2.7 $
+ * @version $Revision: 1.2.2.8 $
  * @since   Horde 2.1
  * @package horde.prefs
  */
@@ -23,8 +21,11 @@ class PrefsUI {
     /**
      * Determine whether or not a preferences group is editable.
      *
+     * @access public
+     *
      * @param string $group  The preferences group to check.
-     * @return boolean       Whether or not the group is editable.
+     *
+     * @return boolean  Whether or not the group is editable.
      */
     function groupIsEditable($group)
     {
@@ -35,7 +36,7 @@ class PrefsUI {
             $results = array();
         }
 
-        if (!isset($results[$group])) {
+        if (!array_key_exists($group, $results)) {
             $results[$group] = false;
             foreach ($prefGroups[$group]['members'] as $pref) {
                 if (!$prefs->isLocked($pref)) {
@@ -54,8 +55,9 @@ class PrefsUI {
      * Handle a preferences form submission if there is one, updating
      * any preferences which have been changed.
      *
-     * @param string $group      The preferences group that was edited.
-     * @return boolean $updated  Whether preferences have been updated.
+     * @param optional string $group  The preferences group that was edited.
+     *
+     * @return boolean  Whether preferences have been updated.
      */
     function handleForm($group = null)
     {
@@ -73,11 +75,11 @@ class PrefsUI {
 
                 foreach ($prefGroups[$group]['members'] as $pref) {
                     if (!$prefs->isLocked($pref) ||
-                        $_prefs[$pref]['type'] == 'special') {
+                        ($_prefs[$pref]['type'] == 'special')) {
                         switch ($_prefs[$pref]['type']) {
 
-                            // These either aren't set or are set in other parts
-                            // of the UI.
+                        /* These either aren't set or are set in other parts
+                           of the UI. */
                         case 'implicit':
                         case 'link':
                             break;
@@ -118,8 +120,8 @@ class PrefsUI {
                             break;
 
                         case 'special':
-                            // Code for special elements must be written
-                            // specifically for each application.
+                            /* Code for special elements must be written
+                               specifically for each application. */
                             if (function_exists('handle_' . $pref)) {
                                 $updated = call_user_func('handle_' . $pref, $updated);
                             }
@@ -172,6 +174,7 @@ class PrefsUI {
             foreach ($prefGroups[$group]['members'] as $pref) {
                 if (!$prefs->isLocked($pref)) {
                     switch ($_prefs[$pref]['type']) {
+
                     case 'implicit':
                         break;
 
@@ -182,6 +185,7 @@ class PrefsUI {
                     default:
                         include $registry->getParam('templates', 'horde') . '/prefs/' . $_prefs[$pref]['type'] . '.inc';
                         break;
+
                     }
                 }
             }
@@ -199,4 +203,3 @@ class PrefsUI {
     }
 
 }
-?>
