@@ -13,10 +13,13 @@
  * Required for some configurations:
  *      'port'          The port on which to connect to the database.
  *
+ * Optional parameters:
+ *      'persistent'     Use persistent DB connections? (boolean)
+ *
  * The table structure can be created by the scripts/db/sessionhandler.sql
  * script.
  *
- * $Horde: horde/lib/SessionHandler/mysql.php,v 1.3.2.2 2003/02/03 10:52:11 jan Exp $
+ * $Horde: horde/lib/SessionHandler/mysql.php,v 1.3.2.4 2003/05/19 17:56:11 slusarz Exp $
  *
  * Copyright 2002-2003 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -24,7 +27,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrame <mike@graftonhall.co.nz>
- * @version $Revision: 1.3.2.2 $
+ * @version $Revision: 1.3.2.4 $
  * @since   Horde 2.2
  * @package horde.session
  */
@@ -97,8 +100,14 @@ class SessionHandler_mysql extends SessionHandler {
         /* Make sure we have a valid database connection. */
         $this->_connect();
 
-        $query = sprintf('SELECT session_data FROM %s WHERE session_id = %s',
-                         $this->_params['table'], $this->_quote($id));
+        /* Session timeout, don't rely on garbage collection */
+        $timeout = time() - ini_get('session.gc_maxlifetime');
+
+        $query = sprintf('SELECT session_data FROM %s WHERE session_id = %s' .
+                         ' AND session_lastmodified > %s',
+                         $this->_params['table'],
+                         $this->_quote($id),
+                         $timeout);
 
         /* Log the query at a DEBUG log level. */
         Horde::logMessage(sprintf('SQL Query by SessionHandler_mysql::read(): query = "%s"', $query),
@@ -224,7 +233,7 @@ class SessionHandler_mysql extends SessionHandler {
     }
 
     /**
-     * Attempts to open a persistent connection to the SQL server.
+     * Attempts to open a connection to the SQL server.
      *
      * @access private
      */
@@ -249,8 +258,7 @@ class SessionHandler_mysql extends SessionHandler {
             $this->_params['table'] = 'horde_sessionhandler';
         }
 
-        if (array_key_exists('persistent', $this->_params) &&
-            !$this->_params['persistent']) {
+        if (empty($this->_params['persistent'])) {
             $connect = 'mysql_connect';
         } else {
             $connect = 'mysql_pconnect';
