@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/db/auth.sql,v 1.5.2.1 2001/12/31 03:16:40 jon Exp $
+-- $Horde: horde/scripts/db/auth.sql,v 1.5.2.2 2002/04/18 22:12:25 jan Exp $
 
 CREATE TABLE horde_users (
     user_uid       varchar(255) not null,
@@ -6,4 +6,4 @@ CREATE TABLE horde_users (
     primary key (user_uid)
 );
 
-grant select, insert, update, delete on horde_users to horde;
+GRANT SELECT, INSERT, UPDATE, DELETE ON horde_users TO horde;
