@@ -1,16 +1,17 @@
--- $Horde: horde/scripts/db/category.sql,v 1.2.2.8 2002/03/11 19:31:35 chuck Exp $
+-- $Horde: horde/scripts/db/category.sql,v 1.2.2.9 2002/08/23 00:30:11 jan Exp $
 
 CREATE TABLE horde_categories (
-       category_id INT not null,
-       group_uid VARCHAR(255) not null,
-       user_uid VARCHAR(255) not null,
-       category_name VARCHAR(255) not null,
+       category_id INT NOT NULL,
+       group_uid VARCHAR(255) NOT NULL,
+       user_uid VARCHAR(255) NOT NULL,
+       category_name VARCHAR(255) NOT NULL,
+       category_parents VARCHAR(255) NOT NULL,
 -- There is no portable way to do this apparently. If your db doesn't allow varchars
 -- greater than 255 characters, then maybe it allows TEXT columns, so try the second
 -- line.
        category_data VARCHAR(2048),
 --     category_data TEXT,
-       category_serialized SMALLINT DEFAULT 0 not null,
+       category_serialized SMALLINT DEFAULT 0 NOT NULL,
        category_updated TIMESTAMP,
        PRIMARY KEY (category_id)
 );
@@ -20,11 +21,4 @@ CREATE INDEX category_group_idx ON horde_categories (group_uid);
 CREATE INDEX category_user_idx ON horde_categories (user_uid);
 CREATE INDEX category_serialized_idx ON horde_categories (category_serialized);
 
-CREATE TABLE horde_categories_categories (
-       category_id_parent INT not null,
-       category_id_child INT not null,
-       PRIMARY KEY (category_id_parent, category_id_child)
-);
-
 GRANT SELECT, INSERT, UPDATE, DELETE ON horde_categories TO horde;
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_categories_categories TO horde;
