@@ -18,18 +18,19 @@ function open_help_win(module, topic)
     if (window.innerWidth) screen_width = window.innerWidth;
     if (window.innerHeight) screen_height = window.innerHeight;
 
+    win_location = '<?php echo Horde::url($registry->getParam('webroot', 'horde') . '/help.php?1=1', true) ?>';
     if (topic == null) {
-        win_location = '/help.php?module=' + module;
+        win_location += '&module=' + module;
     } else if (topic == "") {
-        win_location = '/help.php?module=' + module + '&amp;show=topics';
+        win_location += '&module=' + module + '&show=topics';
     } else {
-        win_location = '/help.php?module=' + module + '&amp;topic=' + topic;
+        win_location += '&module=' + module + '&topic=' + topic;
     }
 
     win_top  = screen_height - help_win_height - 20;
     win_left = screen_width  - help_win_width  - 20;
     HelpWin  = window.open(
-        '<?= $registry->getParam('webroot', 'horde') ?>' + win_location,
+        win_location,
         'HelpWindow',
         'width='+help_win_width+',height='+help_win_height+',top='+win_top+',left='+win_left
     );
